@@ -47,7 +47,7 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
     parser = argparse.ArgumentParser(
         formatter_class=CustomFormatter,
         allow_abbrev=False,
-        description=textwrap.dedent(f"""
+        description=textwrap.dedent(f"""\
             Platoon Formation Simulator (PlaFoSim) -- Version {__version__}.
             A simple and scalable simulator for platoon formation.
 
@@ -622,7 +622,13 @@ def parse_args() -> (argparse.Namespace, argparse._ArgumentGroup):
     # print usage without any arguments
     if len(sys.argv) < 2:
         # no argument has been passed
-        print(parser.format_usage(), parser.description, end='')
+        print(
+            parser.description,
+            '\n',
+            parser.format_usage(),
+            sep='',
+            end='',
+        )
         sys.exit(0)
 
     args = parser.parse_args()
